@@ -135,7 +135,7 @@ namespace DisplayPort
         bool              multistream;
         bool              videoSink, audioSink;
         bool              plugged;
-
+        bool              bApplyPclkWarBug4949066;
 
         AuxRetry          friendlyAux;
         bool              payloadAllocated;             // did the allocate payload go through?
@@ -391,6 +391,10 @@ namespace DisplayPort
             return maxModeBwRequired;
         }
 
+        bool getStuffDummySymbolsFor128b132b() const { return processedEdid.WARData.bStuffDummySymbolsFor128b132b; }
+        bool getStuffDummySymbolsFor8b10b() const { return processedEdid.WARData.bStuffDummySymbolsFor8b10b; }
+        bool getApplyStuffDummySymbolsWAR() const { return processedEdid.WARFlags.bApplyStuffDummySymbolsWAR; }
+
         virtual void queryGUID2();
 
         virtual bool getSDPExtnForColorimetrySupported();
@@ -508,6 +512,9 @@ namespace DisplayPort
         virtual bool getDeviceSpecificData(NvU8 *oui, NvU8 *deviceIdString,
                                            NvU8 *hwRevision, NvU8 *swMajorRevision,
                                            NvU8 *swMinorRevision);
+        virtual bool getParentSpecificData(NvU8 *oui, NvU8 *deviceIdString,
+                                           NvU8 *hwRevision, NvU8 *swMajorRevision,
+                                           NvU8 *swMinorRevision);
 
         virtual bool setModeList(DisplayPort::DpModesetParams *pModeList, unsigned numModes);
     };
