@@ -547,20 +547,23 @@ bool ConnectorImpl2x::compoundQueryAttachMSTGeneric(Group * target,
  */
 bool ConnectorImpl2x::notifyAttachBegin(Group *target, const DpModesetParams &modesetParams)
 {
-    unsigned   twoChannelAudioHz         = modesetParams.modesetInfo.twoChannelAudioHz;
-    unsigned   eightChannelAudioHz       = modesetParams.modesetInfo.eightChannelAudioHz;
-    NvU64      pixelClockHz              = modesetParams.modesetInfo.pixelClockHz;
-    unsigned   rasterWidth               = modesetParams.modesetInfo.rasterWidth;
-    unsigned   rasterHeight              = modesetParams.modesetInfo.rasterHeight;
-    unsigned   rasterBlankStartX         = modesetParams.modesetInfo.rasterBlankStartX;
-    unsigned   rasterBlankEndX           = modesetParams.modesetInfo.rasterBlankEndX;
-    unsigned   depth                     = modesetParams.modesetInfo.depth;
-    bool       bLinkTrainingStatus       = true;
-    bool       bEnableFEC                = true;
-    bool       bEnableDsc                = modesetParams.modesetInfo.bEnableDsc;
-    bool       bEnablePassThroughForPCON = modesetParams.modesetInfo.bEnablePassThroughForPCON;
-    Device     *newDev                   = target->enumDevices(0);
-    DeviceImpl *dev                      = (DeviceImpl *)newDev;
+    unsigned   twoChannelAudioHz             = modesetParams.modesetInfo.twoChannelAudioHz;
+    unsigned   eightChannelAudioHz           = modesetParams.modesetInfo.eightChannelAudioHz;
+    NvU64      pixelClockHz                  = modesetParams.modesetInfo.pixelClockHz;
+    unsigned   rasterWidth                   = modesetParams.modesetInfo.rasterWidth;
+    unsigned   rasterHeight                  = modesetParams.modesetInfo.rasterHeight;
+    unsigned   rasterBlankStartX             = modesetParams.modesetInfo.rasterBlankStartX;
+    unsigned   rasterBlankEndX               = modesetParams.modesetInfo.rasterBlankEndX;
+    unsigned   depth                         = modesetParams.modesetInfo.depth;
+    bool       bLinkTrainingStatus           = true;
+    bool       bEnableFEC                    = true;
+    bool       bEnableDsc                    = modesetParams.modesetInfo.bEnableDsc;
+    bool       bEnablePassThroughForPCON     = modesetParams.modesetInfo.bEnablePassThroughForPCON;
+    Device     *newDev                       = target->enumDevices(0);
+    DeviceImpl *dev                          = (DeviceImpl *)newDev;
+    bool       bApplyStuffDummySymbolsWAR    = this->bApplyStuffDummySymbolsWAR;
+    bool       bStuffDummySymbolsFor128b132b = this->bStuffDummySymbolsFor128b132b;
+    bool       bStuffDummySymbolsFor8b10b    = this->bStuffDummySymbolsFor8b10b;
 
     if(preferredLinkConfig.isValid())
     {
@@ -597,6 +600,14 @@ bool ConnectorImpl2x::notifyAttachBegin(Group *target, const DpModesetParams &mo
         DP_USED(buffer);
         DP_PRINTF(DP_NOTICE, "DP2xCONN>   | %s (%s) |", dev->getTopologyAddress().toString(buffer),
                   dev->isVideoSink() ? "VIDEO" : "BRANCH");
+
+        //
+        // Note: This makes an assumption that all devices in the group have the same values for 
+        //       bApplyStuffDummySymbolsWAR, bStuffDummySymbolsFor8b10b and bStuffDummySymbolsFor128b132b
+        //
+        bApplyStuffDummySymbolsWAR |= ((DeviceImpl *)dev)->getApplyStuffDummySymbolsWAR();
+        bStuffDummySymbolsFor128b132b |= ((DeviceImpl *)dev)->getStuffDummySymbolsFor128b132b();
+        bStuffDummySymbolsFor8b10b |= ((DeviceImpl *)dev)->getStuffDummySymbolsFor8b10b();
     }
 
     if (firmwareGroup && ((GroupImpl *)firmwareGroup)->headInFirmware)
@@ -767,6 +778,16 @@ bool ConnectorImpl2x::notifyAttachBegin(Group *target, const DpModesetParams &mo
         }
     }
     bFromResumeToNAB = false;
+
+    // Apply dummy symbol WAR if link training succeeded and device requires dummy symbols
+    // for the channel coding mode as per the device's WAR flags
+    if (bLinkTrainingStatus && 
+        bApplyStuffDummySymbolsWAR && 
+        ((activeLinkConfig.bIs128b132bChannelCoding && bStuffDummySymbolsFor128b132b) ||
+         ((!activeLinkConfig.bIs128b132bChannelCoding) && bStuffDummySymbolsFor8b10b)))
+    {
+        main->applyStuffDummySymbolWAR(targetImpl->headIndex, true);
+    }
     return bLinkTrainingStatus;
 }
 
@@ -1175,13 +1196,25 @@ bool ConnectorImpl2x::train(const LinkConfiguration &lConfig, bool force, LinkTr
  */
 void ConnectorImpl2x::notifyDetachBegin(Group *target)
 {
+    bool bApplyStuffDummySymbolsWAR = this->bApplyStuffDummySymbolsWAR;
     if (!target)
         target = firmwareGroup;
 
     Device     *newDev  = target->enumDevices(0);
     DeviceImpl *dev     = (DeviceImpl *)newDev;
     GroupImpl  *group   = (GroupImpl*)target; 
+
+    for (Device * d = target->enumDevices(0); d; d = target->enumDevices(d))
+    {
+        DeviceImpl * dev = (DeviceImpl *)d;
+        bApplyStuffDummySymbolsWAR |= dev->getApplyStuffDummySymbolsWAR();
+    }
     
+    if (bApplyStuffDummySymbolsWAR)
+    {
+        main->applyStuffDummySymbolWAR(group->headIndex, false);
+    }
+
     if (dev != NULL && dev->bApplyPclkWarBug4949066 == true)
     {
         EvoInterface   *provider = ((EvoMainLink *)main)->getProvider();
@@ -1719,6 +1752,9 @@ void ConnectorImpl2x::configInit()
     bMstTimeslotBug4968411 = false;
     bApplyManualTimeslotBug4968411 = false;
     bDisableDownspread              = false;
+    bApplyStuffDummySymbolsWAR      = false;
+    bStuffDummySymbolsFor128b132b   = false;
+    bStuffDummySymbolsFor8b10b      = false;
 
     applyDP2xRegkeyOverrides();
 }
