@@ -395,7 +395,24 @@ gsyncAttachGpu(PDACEXTERNALDEVICE pExtDev, OBJGPU *pGpu,
 
     pSys->setProperty(pSys, PDB_PROP_SYS_IS_GSYNC_ENABLED, NV_TRUE);
 
-    return gsyncStartupProvider(pGsync, externalDevice);
+    NV_ASSERT_OK_OR_RETURN(gsyncStartupProvider(pGsync, externalDevice));
+
+    if (pGsync->gpuCount == 1)
+    {
+        //
+        // Initialize the RasterSyncDecodeMode here.
+        // The timing source needs to agree with this, but all GPUs on the GSync
+        // should be the same, so we will use the type of the first GPU
+        //
+        // Errors here should not prevent from loading the Gsync board 
+        //
+        NV_STATUS status;
+
+        NV_CHECK_OK(status, LEVEL_WARNING,
+                pGsync->gsyncHal.gsyncSetRasterSyncDecodeMode(pGpu, pGpu, pGsync->pExtDev));
+    }
+
+    return NV_OK;
 }
 
 //
@@ -2503,23 +2520,10 @@ gsyncNullSetRasterSyncDecodeMode
 )
 {
     //
-    // Performs no action on the Gsync board except for P2061 FW 3.00+
-    // But, this detects when the raster sync mode is not supported by earlier FWs
+    // No action needed on P2061 pre-3.0 FW.
+    // Framelock is not possible on Blackwell with pre-3.0 FW, but that is for
+    // NV_ESC_NVAPI_GSYNC_QUERY_CAPABILITIES.isFirmwareRevMismatch to catch.
     //
-    NV2080_CTRL_INTERNAL_GSYNC_GET_RASTER_SYNC_DECODE_MODE_PARAMS
-            rasterSyncDecodeModeParams;
-    RM_API *pRmApi = GPU_GET_PHYSICAL_RMAPI(pServerGpu);
-
-    // Pre-3.00 FW can only use NV2080_CTRL_CMD_INTERNAL_GSYNC_GET_RASTER_SYNC_DECODE_MODE
-    NV_ASSERT_OK_OR_RETURN(pRmApi->Control(pRmApi, pServerGpu->hInternalClient,
-        pServerGpu->hInternalSubdevice, NV2080_CTRL_CMD_INTERNAL_GSYNC_GET_RASTER_SYNC_DECODE_MODE,
-        &rasterSyncDecodeModeParams, sizeof(rasterSyncDecodeModeParams)));
-
-    NV_CHECK_OR_RETURN(LEVEL_WARNING,
-        rasterSyncDecodeModeParams.rasterSyncDecodeMode ==
-        NV_P2061_CONTROL5_RASTER_SYNC_DECODE_MODE_VSYNC_SHORT_PULSE,
-        NV_ERR_INVALID_OPERATION);
-
     return NV_OK;
 }
 
